/*
-----------------------------------------------------
   Application Name: DIMG
          File Name: utils.cpp
         Start Date: unknown - ask subversion
       Last Changed: $LastChangedDate: 2010-03-30 22:11:50 +1300 (Tue, 30 Mar 2010) $
           Revision: $Revision: 185 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2008,2009,2010
            License: GNU General Public License
   File Description: Various utility functions
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/
#include "utils.h"
#include <QtDebug>

QByteArray utils::swapEndian(QByteArray b){
    QByteArray result;
    for (int i = (b.size() - 1); i >= 0; i--) {
        result.append(b.at(i));
    }

    return result;
}

int utils::byteArrayToIntS(QByteArray b) {
    return byteArrayToInt(swapEndian(b));
}

int utils::byteArrayToInt(QByteArray b) {
    return byteArrayToInt(b,0);
}

int utils::byteArrayToInt(QByteArray b, int offset) {
    // turns four bytes into an integer.
    int value = 0, shift = 0;

    for (int i = 0; i < 4; i++) {
        shift = (3 - i) * 8;
        value += (b.at(i + offset) & 0x000000FF) << shift;
    }
    return value;
}

bool utils::getBit(char byte, int bit) {
    int i = byte >> (bit) & 0x00000001;

    if (i == 1) return true;
    else return false;
}

QByteArray utils::getBytes(QByteArray data, int start, int end, int length) {
    QByteArray qba = getBytes(data,start,end);

    // Now pad out to length.
    int nn = length - qba.size();

    for (int i = 1; i <= nn; i++) {
        qba.append('\0');
    }

    return qba;
}
// 17 18 4
QByteArray utils::getBytes(QByteArray data, int start, int end) {
    if (start < 0) qDebug() << "ERROR: Start is below 0";
    if (start >= data.size()) qDebug() << "ERROR: End is outside array";

    if (start == end) {
        QByteArray qba;
        qba.append(data.at(start));
        return qba;
    }
    if (end == start + 1) {
        QByteArray qba;
        qba.append(data.at(start));
        qba.append(data.at(end));
        return qba;
    }
    return data.mid(start,end-start);
}
